package FreePAN;
use Spoon 0.21 -Base;
our $VERSION = '0.10';

const config_class => 'FreePAN::Config';

__END__

=head1 NAME

FreePAN - FreePAN

=head1 COPYRIGHT

Copyright 2005 by Kang-min Liu <gugod@gugod.org>.

This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

See <http://www.perl.com/perl/misc/Artistic.html>

=cut
